@@ -3,9 +3,10 @@
 # @Time    : 2021/10/19 17:30
 # @Author  : Adyan
 # @File    : index.py
-import json
+
+
 import logging
-from flask import Flask, request, g, jsonify
+from flask import Flask, request, g
 from flask_cors import CORS
 from gevent import monkey
 from gevent.pywsgi import WSGIServer
@@ -43,7 +44,6 @@ def detail():
     s = Scheduler(host, int(port))
     config = s.config
     res = get_conn(config).redis_conn
-    logging.info(key)
     if key == "228923910":
         if res.exists(ip):
             res.setrange(ip, 0, int(res.get(ip)) + 1)
@@ -51,20 +51,22 @@ def detail():
             res.set(ip, 1, ex=3)
         if int(res.get(ip)) < 2:
             # get_conn().put("ssssssss")
-            return json.dumps(
-                {"code": 200, "data": res.srandmember(config.get("PROXY_NAME"), number=count), "msg": ""},
-                ensure_ascii=False
-            )
+            return {
+                "code": 200,
+                "data": [i.decode('utf-8') for i in res.srandmember(config.get("PROXY_NAME"), number=count)],
+            }
         else:
-            return json.dumps(
-                {"code": 111, "data": [], "msg": "请2秒后再试"},
-                ensure_ascii=False
-            )
+            return {
+                "code": 111,
+                "data": [],
+                "msg": "请2秒后再试"
+            }
     else:
-        return json.dumps(
-            {"code": 112, "data": [], "msg": "密匙错误！！！"},
-            ensure_ascii=False
-        )
+        return {
+            "code": 112,
+            "data": [],
+            "msg": "密匙错误！！！"
+        }
 
 
 def main(host, port):
